package com.muyu.market.server.controller;


import com.muyu.common.core.domain.Result;
import com.muyu.market.admain.Product;
import com.muyu.market.admain.request.ProductSaveReq;
import com.muyu.market.admain.request.ProductUpdReq;
import com.muyu.market.admain.response.ProductListResp;
import com.muyu.market.server.service.ProductService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;


@Slf4j
@RestController
@RequestMapping("/product")
@Tag(name = "商品展示控制层",description = "商品展示控制层")
@RequiredArgsConstructor
public class ProductController {


    @Autowired
    private ProductService productService;


    /**
     * 展示商品
     * @param productListResp
     * @return
     */
    @RequestMapping(path = "/productList",method = RequestMethod.POST)
    @Operation(summary = "查询商品接口",description = "根据接口数据可以查看商品信息")
    public Result<List<ProductListResp>> findByproductList(@Validated @RequestBody ProductListResp productListResp){

        return Result.success(productService.findByproductList(productListResp));
    }


    /**
     * 添加接口
     * @param productSaveReq
     * @return
     */
    @PostMapping
    @Operation(summary = "接口信息添加",description = "添加接口信息，添加成功才可以使用")
    public Result<String> save(@Validated @RequestBody ProductSaveReq productSaveReq){
        productService.save(Product.SaveProductList(productSaveReq));
        return Result.success(null,"操作成功");
    }


    /**
     * 修改接口
     * @param productId
     * @param productUpdReq
     * @return
     */
    @PutMapping("/{productId}")
    @Operation(summary = "接口信息的修改",description = "通过Id修改接口信息")
    public Result<String> update(
            @Schema(title = "商品ID",type = "Long",description = "修改商品信息",defaultValue = "1")
            @PathVariable("productId") Long productId,
            @RequestBody @Validated ProductUpdReq productUpdReq){

        productService.updateById(Product.UpdProductList(productUpdReq,()->productId));
        return Result.success(null,"操作成功");
    }



    @DeleteMapping
    @Operation(summary = "信息删除",description = "根据ID删除")
    public Result<String> removeById(@RequestParam(value = "productId") Long productId){
        productService.removeById(productId);
        return Result.success(null,"操作成功");
    }



}
